@@ -3,7 +3,7 @@
 # Copyright 2009 Sun Microsystems Inc.
 # Copyright 2010 Willie Walker
 #  * Contributor: Willie Walker <walker.willie@gmail.com>
-#  * Contributor: Joseph Scheuhammer <clown@utoronto.ca>
+#  * Contributor: Joseph Scheuhammer <clown@alum.mit.edu>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -41,31 +41,19 @@ import debug
 import eventsynthesizer
 import settings
 import orca_state
-import gconf
+from gi.repository.Gio import Settings
 
-from orca_i18n import _
-
-# Some GConf settings that gs-mag uses
+# Some magnfier GSettings
 #
-A11Y_MAG_PREFS_DIR  = "/desktop/gnome/accessibility/magnifier"
-MOUSE_MODE_KEY      = A11Y_MAG_PREFS_DIR + "/mouse_tracking"
-GS_MAG_NONE         = 0
-GS_MAG_CENTERED     = 1
-GS_MAG_PUSH         = 2
-GS_MAG_PROPORTIONAL = 3
-CROSSHAIRS_SHOW_KEY = A11Y_MAG_PREFS_DIR + "/show_cross_hairs"
+MOUSE_MODE_KEY      = "mouse-tracking"
+CROSSHAIRS_SHOW_KEY = "show-cross-hairs"
 
-_gconfClient = gconf.client_get_default()
+_magSettings = Settings('org.gnome.desktop.a11y.magnifier')
 
 # If True, the magnifier is active
 #
 _isActive = False
 
-# Whether or not we're in the process of making "live update" changes
-# to the location of the magnifier.
-#
-_liveUpdatingMagnifier = False
-
 # The current modes of tracking, for use with "live update" changes.
 #
 _controlTracking = None
@@ -204,6 +192,9 @@ def magnifyAccessible(event, obj, extents=None):
     - event: the Event that caused this to be called
     - obj: the accessible
     """
+    if not _initialized:
+        return
+
     haveSomethingToMagnify = False
 
     if extents:
@@ -263,100 +254,6 @@ def magnifyAccessible(event, obj, extents=None):
         elif _controlTracking == settings.MAG_TRACKING_MODE_PUSH:
             _setROICursorPush(x, y, width, height)
 
-########################################################################
-#                                                                      #
-# Methods for updating live tracking settings                          #
-#                                                                      #
-########################################################################
-
-def updateControlTracking(newMode):
-    """Updates the control tracking mode.
-
-    Arguments:
-    -newMode: The new mode to use.
-    """
-    global _controlTracking
-    _controlTracking = newMode
-    
-def updateEdgeMargin(amount):
-    """Updates the edge margin
-
-    Arguments:
-    -amount: The new margin to use, in pixels.
-    """
-    global _edgeMargin
-    _edgeMargin = amount
-
-def updateMouseTracking(newMode):
-    """Updates the mouse tracking mode.
-
-    Arguments:
-    -newMode: The new mode to use.
-    """
-    global _mouseTracking
-    _mouseTracking = newMode
-
-    # Comparing Orca and GS-mag, modes are the same, but different values:
-    # Orca:  centered=0, proportional=1, push=2, none=3
-    # GS-mag: none=0, centered=1, push=2, proportional=3
-    # Use Orca's values as index into following array (hack).
-    #
-    gsMagModes = \
-        [GS_MAG_CENTERED, GS_MAG_PROPORTIONAL, GS_MAG_PUSH, GS_MAG_NONE]
-    _gconfClient.set_int(MOUSE_MODE_KEY, gsMagModes[newMode])
-
-def updatePointerFollowsFocus(enabled):
-    """Updates the pointer follows focus setting.
-
-    Arguments:
-    -enabled: whether or not pointer follows focus should be enabled.
-    """
-    global _pointerFollowsFocus
-    _pointerFollowsFocus = enabled
-
-def updatePointerFollowsZoomer(enabled):
-    """Updates the pointer follows zoomer setting.
-
-    Arguments:
-    -enabled: whether or not pointer follows zoomer should be enabled.
-    """
-    global _pointerFollowsZoomer
-    _pointerFollowsZoomer = enabled
-
-def updateTextTracking(newMode):
-    """Updates the text tracking mode.
-
-    Arguments:
-    -newMode: The new mode to use.
-    """
-    global _textTracking
-    _textTracking = newMode
-
-def finishLiveUpdating():
-    """Restores things that were altered via a live update."""
-
-    global _liveUpdatingMagnifier
-    global _controlTracking
-    global _edgeMargin
-    global _mouseTracking
-    global _pointerFollowsFocus
-    global _pointerFollowsZoomer
-    global _textTracking
-
-    _liveUpdatingMagnifier = False
-    _mouseTracking = settings.magMouseTrackingMode
-    _controlTracking = settings.magControlTrackingMode
-    _textTracking = settings.magTextTrackingMode
-    _edgeMargin = settings.magEdgeMargin
-    _pointerFollowsFocus = settings.magPointerFollowsFocus
-    _pointerFollowsZoomer = settings.magPointerFollowsZoomer
-
-    if settings.enableMagnifier:
-        setupMagnifier(settings.magZoomerType)
-        init()
-    else:
-        shutdown()
-
 ########################################################################
 #                                                                      #
 # Methods for updating appearance settings                             #
@@ -553,8 +450,7 @@ def setupMagnifier(position, left=None, top=None, right=None, bottom=None,
     - bottom:   the top edge of the zoomer (only applicable for custom)
     - restore:  a dictionary of all of the settings that should be restored
     """
-    global _liveUpdatingMagnifier
-    _liveUpdatingMagnifier = True
+
     __setupMagnifier(position, restore)
     __setupZoomer(position, left, top, right, bottom, restore)
 
@@ -586,7 +482,7 @@ def setMagnifierCrossHair(enabled, updateScreen=True):
         size = settings.magCrossHairSize
 
     _magnifier.setCrosswireSize(size)
-    _gconfClient.set_bool(CROSSHAIRS_SHOW_KEY, enabled)
+    _magSettings.set_boolean(CROSSHAIRS_SHOW_KEY, enabled)
 
 def setMagnifierCrossHairClip(enabled, updateScreen=True):
     """Sets the cross-hair clip.
@@ -741,54 +637,6 @@ def setZoomerSmoothingType(smoothingType, updateScreen=True):
     # [[[WDW - To be implemented]]]
     pass
 
-########################################################################
-#                                                                      #
-# Methods for changing settings via keyboard/mouse events              #
-#                                                                      #
-########################################################################
-
-def cycleZoomerType(script=None, inputEvent=None):
-    """Allows the user to cycle through the available zoomer types."""
-    # [[[WDW - To be implemented]]]
-    pass
-
-def decreaseMagnification(script=None, inputEvent=None):
-    """Decreases the magnification level."""
-    # [[[WDW - To be implemented]]]
-    pass
-
-def increaseMagnification(script=None, inputEvent=None):
-    """Increases the magnification level."""
-    # [[[WDW - To be implemented]]]
-    pass
-
-def toggleColorEnhancements(script=None, inputEvent=None):
-    """Toggles the color enhancements on/off."""
-    # [[[WDW - To be implemented]]]
-    pass
-
-def toggleMouseEnhancements(script=None, inputEvent=None):
-    """Toggles the mouse enhancements on/off."""
-    # [[[WDW - To be implemented]]]
-    pass
-
-def toggleMagnifier(script=None, inputEvent=None):
-    """Toggles the magnifier."""
-    if not _magnifier.isActive():
-        init()
-        # Translators: this is the message spoken when a user enables the
-        # magnifier.  In addition to screen magnification, the user's
-        # preferred colors and mouse customizations are loaded.
-        #
-        orca_state.activeScript.presentMessage(_("Magnifier enabled."))
-    else:
-        shutdown()
-        # Translators: this is the message spoken when a user disables the
-        # magnifier, restoring the screen contents to their normal colors
-        # and sizes.
-        #
-        orca_state.activeScript.presentMessage(_("Magnifier disabled."))
-
 ########################################################################
 #                                                                      #
 # Methods for obtaining magnifier capabilities                         #
@@ -832,7 +680,7 @@ def init():
     try:
         _initialized = True
         _wasActiveOnInit = _magnifier.isActive()
-        _crossHairsShownOnInit = _gconfClient.get_bool(CROSSHAIRS_SHOW_KEY)
+        _crossHairsShownOnInit = _magSettings.get_boolean(CROSSHAIRS_SHOW_KEY)
         applySettings()
         _magnifier.setActive(True)
         _isActive = _magnifier.isActive()
@@ -855,7 +703,7 @@ def shutdown():
         return False
 
     _magnifier.setActive(_wasActiveOnInit)
-    _gconfClient.set_bool(CROSSHAIRS_SHOW_KEY, _crossHairsShownOnInit)
+    _magSettings.set_boolean(CROSSHAIRS_SHOW_KEY, _crossHairsShownOnInit)
     _isActive = _magnifier.isActive()
     if not _isActive:
         hideSystemPointer(False)
