@@ -33,7 +33,6 @@ import settings
 import speech
 import speechserver
 import orca
-import orca_prefs
 import time
 
 desktopRunning = False
@@ -130,8 +129,8 @@ def setupSpeech(prefsDict):
     global speechServerChoice
     global speechVoiceChoice
 
-    # Use this because callbacks will often hang when not running
-    # with bonobo main in use.
+    # Use this because callbacks in this setup can hang.
+    # TODO: Is this true still??
     #
     settings.enableSpeechCallbacks = False
 
@@ -171,10 +170,9 @@ def setupSpeech(prefsDict):
         return False
     elif len(workingFactories) > 1:
         # Translators: the speech system represents what general
-        # speech wrapper is going to be used.  For example,
-        # gnome-speech is a speech system, speech dispatcher is
-        # another, emacspeak is another.  These all then provide
-        # wrappers around specific speech servers (engines).
+        # speech wrapper is going to be used.  Speech-dispatcher
+        # is an example of a speech system. It provides wrappers
+        # around specific speech servers (engines).
         #
         sayAndPrint(_("Select desired speech system:"))
         choices = {}
@@ -568,22 +566,6 @@ def showPreferencesUI(commandLineSettings):
             sayAndPrint(_("Please enter y or n."))
 
     stop = True
-    while True:
-        # Translators: orca can be set up to automatically start when
-        # the user logs in.
-        #
-        answer = sayAndPrint(_("Automatically start orca when you log in?  " \
-                                   "Enter y or n: "),
-                             stop,
-                             True,
-                             speechServerChoice,
-                             speechVoiceChoice)
-        try:
-            autostart = checkYes(answer)
-            break
-        except:
-            stop = False
-            sayAndPrint(_("Please enter y or n."))
 
     _settingsManager.setFirstStart(False)
 
@@ -624,16 +606,10 @@ def showPreferencesUI(commandLineSettings):
                                     speechServerChoice,
                                     speechVoiceChoice)
                         time.sleep(2)
-                        settings.setOrcaAutostart(autostart)
 
                         import gobject
                         gobject.threads_init()
                         gobject.idle_add(logoutUser)
-                        try:
-                            import bonobo
-                            bonobo.main()
-                        except:
-                            pass
                     break
                 except:
                     stop = False
@@ -645,8 +621,6 @@ def showPreferencesUI(commandLineSettings):
                          speechServerChoice,
                          speechVoiceChoice)
 
-    settings.setOrcaAutostart(autostart)
-
     for [factory, servers] in workingFactories:
         factory.SpeechServer.shutdownActiveServers()
 
