@@ -41,7 +41,7 @@ import gtk
 import pyatspi
 
 import orca.debug as debug
-import orca.default as default
+import orca.scripts.default as default
 import orca.input_event as input_event
 import orca.orca as orca
 import orca.orca_state as orca_state
@@ -113,12 +113,6 @@ class Script(default.Script):
         #
         self.currentParagraph = None
 
-        # Set the number of retries after a COMM_FAILURE to 1. The default
-        # of 5 was not allowing Orca to be responsive in the event of OOo
-        # going into crash recovery mode (see bug #397787).
-        #
-        self.commFailureAttemptLimit = 1
-
     def activate(self):
         """Called when this script is activated."""
         self.savedreadTableCellRow = \
@@ -149,6 +143,8 @@ class Script(default.Script):
         attributes.replace("indent:0;", "indent:0mm;")
         _settingsManager.setSetting('enabledSpokenTextAttributes', attributes)
 
+        default.Script.activate(self)
+
     def deactivate(self):
         """Called when this script is deactivated."""
         _settingsManager.setSetting('readTableCellRow',
@@ -158,6 +154,8 @@ class Script(default.Script):
         _settingsManager.setSetting('enabledSpokenTextAttributes',
                                     self.savedEnabledSpokenTextAttributes)
 
+        default.Script.activate(self)
+
     def getListeners(self):
         """Sets up the AT-SPI event listeners for this script.
         """
@@ -403,6 +401,7 @@ class Script(default.Script):
 
         prefs.writelines("\n")
         prefix = "orca.scripts.apps.soffice.script_settings"
+        prefs.writelines("import %s\n\n" % prefix)
 
         script_settings.speakSpreadsheetCoordinates = \
             self.speakSpreadsheetCoordinatesCheckButton.get_active()
@@ -1817,7 +1816,7 @@ class Script(default.Script):
             if presentEvent:
                 speech.stop()
             orca.setLocusOfFocus(
-                event, event.any_data, notifyPresentationManager=presentEvent)
+                event, event.any_data, notifyScript=presentEvent)
 
             # We'll tuck away the activeDescendant information for future
             # reference since the AT-SPI gives us little help in finding
@@ -1976,8 +1975,7 @@ class Script(default.Script):
                          pyatspi.ROLE_ROOT_PANE,
                          pyatspi.ROLE_FRAME]
             if self.utilities.hasMatchingHierarchy(event.source, rolesList):
-                orca.setLocusOfFocus(
-                    event, event.source, notifyPresentationManager=False)
+                orca.setLocusOfFocus(event, event.source, notifyScript=False)
                 if event.source != self.currentParagraph:
                     self.updateBraille(event.source)
                 return
@@ -1990,7 +1988,7 @@ class Script(default.Script):
             elif event.source.parent and \
                 event.source.parent.getRole() == pyatspi.ROLE_COMBO_BOX:
                 orca.setLocusOfFocus(
-                    None, event.source.parent, notifyPresentationManager=False)
+                    None, event.source.parent, notifyScript=False)
                 return
 
         # If we are in the sbase Table Wizard, try to reduce the numerous
