@@ -48,11 +48,6 @@ try:
     _screen = _display.get_default_screen()
     _root_window = _screen.get_root_window()
 
-    # These are used for placing the magnifier zoomer.
-    #
-    screenWidth = _screen.get_width()
-    screenHeight = _screen.get_height()
-
     # The bug that caused gnome-panel to crash is fixed in GTK 2.10.11.
     minimum_gtk_version = (100000 * 2) + \
                           (1000 * 10) + \
@@ -70,12 +65,6 @@ try:
 except:
     pass
 
-try:
-    import gconf
-    gconfClient = gconf.client_get_default()
-except:
-    gconfClient = None
-
 import pyatspi
 
 from acss import ACSS
@@ -120,45 +109,6 @@ userCustomizableSettings = [
     "brailleLinkIndicator",
     "brailleAlignmentStyle",
     "enableBrailleMonitor",
-    "enableMagnifier",
-    "enableMagLiveUpdating",
-    "enableMagCursor",
-    "enableMagCursorExplicitSize",
-    "magHideCursor",
-    "magCursorSize",
-    "magCursorColor",
-    "enableMagCrossHair",
-    "enableMagCrossHairClip",
-    "magCrossHairSize",
-    "magCrossHairColor",
-    "magZoomerType",
-    "magZoomerLeft",
-    "magZoomerRight",
-    "magZoomerTop",
-    "magZoomerBottom",
-    "magZoomFactor",
-    "enableMagZoomerBorder",
-    "magZoomerBorderSize",
-    "magZoomerBorderColor",
-    "enableMagZoomerColorInversion",
-    "magBrightnessLevel",
-    "magBrightnessLevelRed",
-    "magBrightnessLevelBlue",
-    "magBrightnessLevelGreen",
-    "magContrastLevel",
-    "magContrastLevelRed",
-    "magContrastLevelGreen",
-    "magContrastLevelBlue",
-    "magSmoothingMode",
-    "magMouseTrackingMode",
-    "magControlTrackingMode",
-    "magTextTrackingMode",
-    "magEdgeMargin",
-    "magPointerFollowsFocus",
-    "magPointerFollowsZoomer",
-    "magColorFilteringMode",
-    "magSourceDisplay",
-    "magTargetDisplay",
     "verbalizePunctuationStyle",
     "showMainWindow",
     "quitOrcaNoConfirmation",
@@ -391,8 +341,7 @@ onlySpeakDisplayedText = False
 # Settings that apply to the particular speech engine to
 # use as well details on the default voices to use.
 #
-speechFactoryModules    = ["gnomespeechfactory",
-                           "speechdispatcherfactory",
+speechFactoryModules    = ["speechdispatcherfactory",
                            "espeechfactory"]
 speechServerFactory     = "speechdispatcherfactory"
 speechServerInfo        = None # None means let the factory decide.
@@ -459,12 +408,6 @@ enableBrailleMonitor    = False
 #
 enableMagnifier                  = False
 
-# If True, changes made in the Magnifier pane will take place
-# immediately (i.e. without pressing the apply button).  Making
-# them permanent still requires pressing Apply or OK.
-#
-enableMagLiveUpdating            = True
-
 # If True, show the magnification cursor.
 #
 enableMagCursor                  = True
@@ -614,11 +557,11 @@ magPointerFollowsZoomer        = True
 
 # Magnification source display
 #
-magSourceDisplay                 = ''
+magSourceDisplay                 = ':0.0'
 
 # Magnification target display
 #
-magTargetDisplay                 = ''
+magTargetDisplay                 = ':0.0'
 
 # if True, enable character echo.
 # Note that it is allowable for both enableEchoByCharacter and enableKeyEcho
@@ -892,15 +835,6 @@ listShortcutsModeEnabled = False
 from xdg.BaseDirectory import xdg_data_home
 userPrefsDir = os.path.join(xdg_data_home, "orca")
 
-# Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
-# always mean an object disappeared - there just might be a network
-# glitch.  So, on COMM_FAILURES, we might retry a few times before
-# giving up on an object.  This might need to be overridden by the
-# script.
-#
-commFailureWaitTime = 0.1
-commFailureAttemptLimit = 5
-
 # If non-zero, we use time.sleep() in various places to attempt to
 # free up the global interpreter lock.  Take a look at the following
 # URLs for more information:
@@ -921,11 +855,6 @@ useGILIdleHandler       = False
 #
 useBlockPreventor       = False
 
-# If True, we use the bonobo main loop provided by bonobo to handle
-# all events in atspi.py.  If False, we create our own loop.
-#
-useBonoboMain           = False
-
 # If True, we handle events asynchronously - our normal mode of
 # queueing events and processing them later on the gidle thread.
 # If False, we handle events immediately - helpful for testing.
@@ -936,7 +865,7 @@ asyncMode               = True
 # This was originally added for the Java toolkit (see bug #531869), but
 # we put this here to allow more toolkits to be more easily added.
 #
-synchronousToolkits     = []
+synchronousToolkits     = ['VCL']
 
 # If True, we output debug information for the event queue.  We
 # use this in addition to log level to prevent debug logic from
@@ -986,50 +915,6 @@ chatAnnounceBuddyTyping = False
 #
 chatRoomHistories = False
 
-# Obtain/set information regarding whether Orca is autostarted for this
-# user at login time.
-#
-def isOrcaAutostarted():
-    """Return an indication of whether Orca autostart at login time is enabled.
-    """
-    prefix = "/desktop/gnome/applications/at/visual/"
-    try:
-        return ("orca" in gconfClient.get_string(prefix + "exec")) \
-           and gconfClient.get_bool(prefix + "startup")
-    except:
-        return False
-
-def setOrcaAutostart(enable):
-    """Enable or disable the autostart of Orca at login time.
-
-    Arguments:
-    - enable: if True, whether Orca autostart at login time is enabled.
-
-    Returns an indication of whether the operation was successful.
-    """
-    prefix = "/desktop/gnome/applications/at/visual/"
-    try:
-        return gconfClient.set_string(prefix + "exec", "orca") \
-           and gconfClient.set_bool(prefix + "startup", enable)
-    except:
-        return False
-
-# Obtain/set information regarding whether the gksu keyboard grab is enabled
-# or not.
-#
-def isGKSUGrabDisabled():
-    try:
-        return gconfClient.get_bool("/apps/gksu/disable-grab")
-    except:
-        return False
-
-def setGKSUGrabDisabled(disable):
-    try:
-        return gconfClient.set_bool("/apps/gksu/disable-grab",
-                                    disable)
-    except:
-        return False
-
 # Allow for the customization of key bindings.
 #
 def overrideKeyBindings(script, keyBindings):
