@@ -54,9 +54,8 @@ class SettingsManager(object):
     def __init__(self, backend='json'):
         """Initialize a SettingsManager Object.
         If backend isn't defined then uses default backend, in this
-        case gconf-backend.
+        case json-backend.
         backend parameter can use the follow values:
-        backend='gconf'
         backend='json'
         """
 
@@ -372,7 +371,7 @@ class SettingsManager(object):
                 continue
             elif key == 'profile':
                 self.profileGeneral[key] = value
-            elif value != self.defaultGeneralValues[key]:
+            elif value != self.defaultGeneralValues.get(key):
                 self.profileGeneral[key] = value
             elif self.general.get(key) != value:
                 self.profileGeneral[key] = value
